Configuration setting
Set the student-view, client side configurations for RecommenderXblock.
Do you want to take users on a little tour when they see the RecommenderXBlock first time?
Do you want to disable the UX functions which are under development?
How many resources you want to show in each page of the resource list?
How many page icons in pagination control (i.e., page range)? The icons for pages from (current page - page range) to (current page + page range) will be shown.